@@ -496,8 +496,8 @@ sub lookup_object_of_method($$)
     }
     else
     {
-      print "DocsParser.pm:lookup_object_of_method(): Warning: GtkDefs::lookup_object() failed for function name=" . $name . "\n";
-      print "  This may be a missing define-object in a *.defs file."
+      print "DocsParser.pm:lookup_object_of_method(): Warning: GtkDefs::lookup_object() failed for object name=" . $object . ", function name=" . $name . "\n";
+      print "  This may be a missing define-object in a *.defs file.\n"
     }
   }
 
